package service

import (
	"github.com/pocketbase/pocketbase"
	"github.com/pocketbase/pocketbase/core"
	"github.com/pocketbase/pocketbase/tools/cron"
	"htwkalender/service/events"
	"log"
)

func AddSchedules(app *pocketbase.PocketBase) {

	app.OnBeforeServe().Add(func(e *core.ServeEvent) error {
		scheduler := cron.New()

		// Every hour update all courses (5 segments - minute, hour, day, month, weekday) "0 * * * *"
		// Every three hours update all courses (5 segments - minute, hour, day, month, weekday) "0 */3 * * *"
		// Every 10 minutes update all courses (5 segments - minute, hour, day, month, weekday) "*/10 * * * *"
		scheduler.MustAdd("updateCourse", "0 */3 * * *", func() {

			courses := events.GetAllCourses(app)

			for _, course := range courses {
				err := events.UpdateModulesForCourse(app, course)
				if err != nil {
					log.Println("Update Course: " + course + " failed")
					log.Println(err)
				} else {
					log.Println("Update Course: " + course + " successful")
				}
			}

		})

		scheduler.Start()

		return nil
	})

}
